ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
    OutPoint,
    Transaction,
    SubmitTransaction,
    Script,
    Header,
    Block,
    Internal,
    Dao,
    Spec,
}
A list specifying categories of ckb error.

This list is intended to grow over time and it is not recommended to exhaustively match against it.

It is used with Error.

Variants



OutPoint

It indicates that the underlying error is OutPointError.



Transaction

It indicates that the underlying error is TransactionError.



SubmitTransaction

It indicates that the underlying error is Reject.



Script

It indicates that the underlying error is TransactionScriptError.



Header

It indicates that the underlying error is HeaderError.



Block

It indicates that the underlying error is BlockError



Internal

It indicates that the underlying error is InternalError



Dao

It indicates that the underlying error is DaoError



Spec

It indicates that the underlying error is SpecError

Implementations

Source

impl ErrorKind

pub fn because<E>(self, reason: E) -> Error
where E: Error + Send + Sync + 'static,

Creates Error base on ErrorKind with an error as the reason.

pub fn other<T>(self, reason: T) -> Error
where T: Display,

Creates Error base on ErrorKind with a simple string as the reason.