pub enum InternalErrorKind {
    CapacityOverflow,
    DataCorrupted,
    Database,
    BlockAssembler,
    VM,
    MMR,
    System,
    Config,
    Other,
}
A list specifying categories of ckb internal error.

This list is intended to grow over time and it is not recommended to exhaustively match against it.

It is used with the InternalError.

Variants

CapacityOverflow

An arithmetic overflow occurs during capacity calculation, e.g. Capacity::safe_add

DataCorrupted

Persistent data had corrupted

Database

Error occurs during database operations

BlockAssembler

It indicates that the underlying error is BlockAssemblerError

VM

VM internal error

MMR

MMR internal error

System

Unknown system error

Config

The feature is disabled or is conflicted with the configuration

Other

Other system error

Implementations

Creates InternalError base on InternalErrorKind with an error as the reason.

Creates InternalError base on InternalErrorKind with a simple string as the reason.