Struct ckb_error::OtherError [−][src]
pub struct OtherError(_);
An error with only a string as the reason.
Implementations
impl OtherError[src]
impl OtherError[src]Trait Implementations
impl Clone for OtherError[src]
impl Clone for OtherError[src]fn clone(&self) -> OtherError[src]
fn clone(&self) -> OtherError[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for OtherError[src]
impl Debug for OtherError[src]impl Display for OtherError[src]
impl Display for OtherError[src]impl Error for OtherError[src]
impl Error for OtherError[src]fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]
fn source(&self) -> Option<&(dyn Error + 'static)>1.30.0[src]The lower-level source of this error, if any. Read more
fn backtrace(&self) -> Option<&Backtrace>[src]
fn backtrace(&self) -> Option<&Backtrace>[src]🔬 This is a nightly-only experimental API. (
backtrace)Returns a stack backtrace, if available, of where this error occurred. Read more
fn description(&self) -> &str1.0.0[src]
fn description(&self) -> &str1.0.0[src]👎 Deprecated since 1.42.0:
use the Display impl or to_string()
impl From<OtherError> for InternalError[src]
impl From<OtherError> for InternalError[src]fn from(error: OtherError) -> Self[src]
fn from(error: OtherError) -> Self[src]Performs the conversion.
impl From<OtherError> for Error[src]
impl From<OtherError> for Error[src]fn from(error: OtherError) -> Self[src]
fn from(error: OtherError) -> Self[src]Performs the conversion.